#ifndef NT2_INCLUDE_FUNCTIONS_NULL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NULL_HPP_INCLUDED

#include <nt2/linalg/include/functions/null.hpp>

#endif
